==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
export let WebForOfStateEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
                WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebForOfStateEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebForOfStateEventArgsDescriptionMetadata.a);
            WebForOfStateDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebForOfStateDetail");
        }
        static d(a) {
            WebForOfStateEventArgsDescriptionMetadata.b(a);
            a.ad("WebForOfStateEventArgs", () => new WebForOfStateEventArgsDescription());
            a.ac("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
        }
    }
    WebForOfStateEventArgsDescriptionMetadata.$t = markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
export let WebForOfStateEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
                WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebForOfStateEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebForOfStateEventArgsDescriptionMetadata.a);
            WebForOfStateDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebForOfStateDetail");
        }
        static d(a) {
            WebForOfStateEventArgsDescriptionMetadata.b(a);
            a.ae("WebForOfStateEventArgs", () => new WebForOfStateEventArgsDescription());
            a.ad("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
        }
    }
    WebForOfStateEventArgsDescriptionMetadata.$t = markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
})();
